@@ -18,6 +18,8 @@ Examples
 ==
 ?- exo.
 ?- exo([]).
+% Using debug_call, at version: 2:1:1 (published on: date(2025,12,6))
+% Using exo, at version: 0:3 (published on: 25.12.6)
 % Predicate: exo/1 option selected: op1(one).
 % Predicate: exo/1 options: [debug(true),op1(one),op2(two)]
 % Predicate: exo/1 options: [$restore(exo,debug,true),$restore(exo,debug,false),debug(true),op1(one),op2(two)]
@@ -46,6 +48,10 @@ Examples
 % 2.b
 % 3.c
 % Ended enumeration of term: term_abc (func: t)
+% Starting enumeration of list: list3
+% 1.a
+% 2.b
+% ... + 1 other element
 % My message is long.
 % Why predicate: exo/1 my message is long ?
 % Dimensions for matrix, mtxo: nR: 4, nC: 3.
@@ -60,6 +66,7 @@ Examples
 % At 15:50:4 on 27th of Oct 2025 stop task: write on file.
 % At 15:50:4 on 27th of Oct 2025 unk task: write on file.
 % Prefixed by predicate: exo/1 at 15:50:4 on 27th of Oct 2025 unk task: write on file.
+% At 14:2:30 on 6th of Dec 2025 stop task: talking point
 % Starting: my_run
 % From predicate: exo/1 starting: my_run
 % Pwd at, my_run, is: '/home/nicos/pl/packs/private/debug_call/'
@@ -70,6 +77,24 @@ Examples
 % By call predicate: exo/1 avg: 2, list: [1,2,3]
 % pfx1 finished: exo
 % At predicate: exo/1 finished: exo
+% Session Info
+% Interpreter is SWI-Prolog 9:3:34, [Git: 9.3.34-41-g8cf975236].
+% Packs with predicated version info.
+% debug_call-2:1:1@<date(2025,12,6) (Pack file version: 2.1)
+% options-1:5:0@<date(2022,12,29) (Pack file version: 1.5)
+% Pack with version from pack file only.
+% lib-2.11
+% System boot files loaded.
+% boot/init.pl
+% boot/messages.pl
+% boot/syspred.pl
+% System libraries loaded.
+% ansi_term.pl
+% lists.pl
+% There is one application file loaded.
+% /home/nicos/.local/share/swi-prolog/pack/debug_call/examples/exo.pl
+% Session Info End
+% Finished: exo
 % Finished: exo
 true.
 ==
@@ -77,6 +102,7 @@ true.
 @author nicos angelopoulos
 @version  0.1 2025/10/07
 @version  0.2 2025/10/27
+@version  0.3 2025/12/6
 
 */
 exo :-
@@ -84,6 +110,8 @@ exo :-
 exo( Args ) :-
      Self = exo,
      options_append( Self, Args, Opts ),
+     debuc( Self, version, debug_call ),
+     debuc( Self, version, v(exo,0:3,'25.12.6') ),
      options( op1(Op1), Opts ),
      debuc( Self, option, op1(Op1), pred(exo/1) ),
      debuc( Self, options, Opts, pred(exo/1) ),
@@ -107,6 +135,7 @@ exo( Args ) :-
      debuc( Self, list, ops/ops/Ops, true ),
      debuc( Self, enum, ops/Ops, prefix('Abc') ),
      debuc( Self, enum, term_abc/t(a,b,c) ),
+     debuc( Self, enum, list3/[a,b,c], depth(2) ),
      debuc( Self, info, 'My message is ~w.'/long ),
           % ^ written in Green
      debuc( Self, info, 'My message is ~w ?'/long, [pred(Self,1),prefix('Why')] ),
@@ -132,6 +161,7 @@ exo( Args ) :-
      debuc( Self, task(stop), 'write on file' ),
      debuc( Self, task(unk), 'write on file' ),
      debuc( Self, task(unk), 'write on file', [prefix('Prefixed by'),pred(Self,1)] ),
+     debuc( Self, task(stop), 'talking ~w', [farg(point)] ),
      debuc( Self, start, my_run ),
      debuc( Self, start, my_run, [prefix('From'),pred(Self,1)] ),
      debuc( Self, pwd, my_run ),
@@ -146,4 +176,5 @@ exo( Args ) :-
      abolish( list_avg_mess/3 ),
      debuc( Self, end, true, prefix(pfx1) ),
      debuc( Self, end, true, [prefix('At'),pred(Self,1)] ),
+     debuc( Self, session, true ),
      debuc( Self, end, true ).
