@@ -28,23 +28,24 @@ user:message_property( Dbg, Property ) :-
 Avoids running goals to produce output that is only relevant while debugging.
 Includes pre-canned, often used calls that print informative messages for common debugging tasks.
 
+See the main predicate's documenation, debug_call/4, for more details.<br>
 See file examples/exo.pl for a full pallette of examples. 
 
 ---+++ Examples
 
 ==
 
-?- debug( ex ).
-?- debug_call( ex, length, list1/[x,y,z] ).
+?- debug(ex).
+?- debug_call(ex, length, list1/[x,y,z]).
 % Length for list, list1: 3
 
-?- debug_call( ex, length, [list1,list2]/[[x,y,z],[a,b,c]], prefix('Some prefix') ).
+?- debug_call(ex, length, [list1,list2]/[[x,y,z],[a,b,c]], prefix('Some prefix')).
 % Some prefix lengths for lists, list1: 3, list2: 3
 
-?- debug_call( ex, dims, [m1,m2]/[[a(x),a(y),a(z)],[xy(a,b),xy(c,d),xy(e,f)]] ).
+?- debug_call(ex, dims, [m1,m2]/[[a(x),a(y),a(z)],[xy(a,b),xy(c,d),xy(e,f)]]).
 %  Dimensions for matrices,  (m1) nR: 3, nC: 1. (m2) nR: 3, nC: 2.
 
-?- debug_call( ex, enum, testo/[a,b,c] ).
+?- debug_call(ex, enum, testo/[a,b,c]).
 % Starting enumeration of list: testo
 % 1.a
 % 2.b
@@ -52,23 +53,37 @@ See file examples/exo.pl for a full pallette of examples.
 % Ended enumeration of list: testo
 true.
 
-?- debug_call( ex, info, 'My message is ~w.'/long ).
+?- debug_call(ex, enum, testo/[a,b,c,d,e], depth(3)).
+% Starting enumeration of list: testo
+% 1.a
+% 2.b
+% 3.c
+% ... + 2 other elements
+% Ended enumeration of list: testo
+
+?- debug_call(ex, info, 'My message is ~w.'/long).
 % My message is long.
 true.    
    % message above is printed in informational colour
 
-?- debuc( ex, wrote, loc(file,csv) ).
+?- debuc(ex, wrote, loc(file,csv)).
 % Could not locate wrote on file specified by: file, and extensions: csv
-?- csv_write_file( 'file.csv', [] ).
+?- csv_write_file('file.csv', []).
 
-?- debuc( ex, wrote, loc(file,csv) ).
+?- debuc(ex, version, debug_call).
+% Using debug_call_version, at version: 2:1:1 (published on: date(2025,12,6)).
+
+?- debuc(ex, wrote, loc(file,csv)).
 % Wrote on file: 'file.csv'
 
-?- debuc( ex, task(stop), 'write on file' ).
+?- debuc(ex, task(stop), 'write on file').
 At 15:44:1 on 2nd of Jul 2024 finished task: write on file.
 
-?- assert( (simple_mess(KVs,Mess,Args):- KVs =[a=A,b=B], atom_concat(A,B,Mess), Args=[]) ).
-?- debuc( ex, simple_mess([a=1,b=2]) ).
+?- debuc(ex, task(stop), 'talking ~w', [farg(point)]).
+% At 13:58:50 on 6th of Dec 2025 stop task: talking point
+
+?- assert((simple_mess(KVs,Mess,Args):- KVs =[a=A,b=B], atom_concat(A,B,Mess), Args=[])).
+?- debuc(ex, simple_mess([a=1,b=2])).
 % 12
 true.
 ==
@@ -97,7 +112,8 @@ debug_calls uses dynamic =..  .
 @version 1.5 2022/12/29
 @version 2.0 2025/10/7
 @version 2.1 2025/10/27
-@see debug_call/4 for version information
+@version 2.2 2025/12/8
+@see debug_call/4 for information on what each version added.
 
 */
 
@@ -107,11 +123,11 @@ Current version and release date for the library.
 
 ==
 ?- debug_call_version( -V, -D ).
-V = 2:1:0,
-D = date(2025,10,27).
+V = 2:2:0,
+D = date(2025,12,8).
 ==
 */
-debug_call_version( 2:1:0, date(2025,10,27) ).
+debug_call_version(2:2:0, date(2025,12,8)).
 
 :- use_module(library(apply)).   % maplist/4,...
 :- use_module(library(lists)).   % member/4,...
@@ -158,8 +174,10 @@ debuc( Topic, Goal, Arg, Opts ) :-
 % 
 % Examples
 %==
-% ?- assert( (simple_mess(KVs,Mess,Args):- KVs =[a=A,b=B], atom_concat(A,B,Mess), Args=[]) ).
-% ?- debug_call( ex, simple_mess([a=1,b=2], 
+% ?- debug(ex)
+% ?- assert((simple_mess(KVs,Mess,Args):- KVs =[a=A,b=B], atom_concat(A,B,Mess), Args=[])).
+% ?- debug_call(ex, simple_mess([a=1,b=2])).
+% 12
 %==
 %
 % @author nicos angelopoulos
@@ -425,62 +443,74 @@ debug_portray( _Topic, _Term ).
 %
 % Goal in:
 %  * call(Goal)
-%    call Goal before printing debugging message debug(Topic, Mess, MArgS).  Goal is called in deterministic context.
+%    Call Goal before printing debugging message debug(Topic, Mess, MArgS).  Goal is called in deterministic context.
 %    Goal is called with extra arguments +Arg, -Mess and -MArgS.
-%  * call(Goal,Opts) 
-%    as above, but Opts are passed as an extra, last argument in the call
+%  * call(Goal,Opts)
+%    As above, but Opts are passed as an extra, last argument in the call.
 %  * dims
-%    prints the dimensions of matrix, see mtx_dims/3
+%    Prints the dimensions of matrix, see mtx_dims/3.
 %  * end
-%    translates to finishing ~Arg or finishing ~Topic if Arg == true
+%    Translates to finishing ~Arg or finishing ~Topic if Arg == true.
 %  * enum
-%    print members of lists and arguments of terms, where each item is printed on single line and prefixed by an index number
+%    Print members of lists and arguments of terms, where each item is printed on single line and prefixed by an index number
+%    Knows: depth(Depth) (restricts items to print).
 %  * goal
-%    anything that does n't match any of the above is retrived as call(Goal)
+%    Anything that does n't match any of the above is retrived as call(Goal)
 %  * info
-%    print using informational machinery (usually different/green colour, to debug's blue)
+%    Print using informational machinery (usually different/green colour, to debug's blue)
 %    term should Mess/Args in the debug/3 version
 %  * input
-%    reports reading from a file. Arg should be file specification suitable for locate/3.
+% At 14:2:30 on 6th of Dec 2025 stop task: talking point
+%    Reports reading from a file. Arg should be file specification suitable for locate/3.
 %    Either loc(File,Exts) or simply File in which case Exts = ''.
 %    As of v2.0 the default is to print the basename, use path(abs) in Opts.
 %  * length
-%    prints the lenghts of a bunch of lists. Args should be ListNames/Lists. 
+%    Prints the lenghts of a bunch of lists. Args should be ListNames/Lists. 
 %    uses non list ListNames if debuging the length of a single list, in which case
 %    message in the singular is used.
 %  * list
-%    writes contents of list with header and footer. Arg should be of the form Hdr/Ftr/List, 
-%    else it is translated as Hdr/''/List or ''/''/List. 
-%    If Hdr or Ftr are '' then that part of the message is skipped
+%    Writes contents of list with header and footer. Arg should be of the form Hdr/Ftr/List, 
+%    else Hdr/List unfolds to Hdr/Hdr/List and List is translated to unknown/unknown/List. 
+%    Knows: depth(Depth) (restricts items to list).
 %  * ns_sel
-%    first argument of Arg is the item selected from second arg which is expected to be a list.
+%    First argument of Arg is the item selected from second arg which is expected to be a list.
 %    The selected argument can be named on the massage via sel_name(Lnm) in Opts.
 %  * odir
-%    output directory (Arg should exist and be a directory)
+%    Output directory (Arg should exist and be a directory)
 %  * option
-%    option selected from options for predicate. Possible options: pred(Fnc,Ar) or pred(Pid), the caller predicate, all(OrigOpts), shows all options, 
+%    Option selected from options for predicate. Possible options: pred(Fnc,Ar) or pred(Pid), the caller predicate, all(OrigOpts), shows all options, 
 %    internal(true), shows also '$' starting options.
 %  * options
-%    options used on call to a predicate. Possible options: pred(Func,Ar), pred(Pid), the caller predicate, internal(true), shows also '$' starting options.
+%    Options used on call to a predicate. Possible options: pred(Func,Ar), pred(Pid), the caller predicate, internal(true), shows also '$' starting options.
 %  * pwd 
-%    message about current dir Location (=Arg), (if Arg == false, location is not shown)- see examples
+%    Message about current dir Location (=Arg), (if Arg == false, location is not shown)- see examples.
 %  * read
-%    alias for input
+%    Alias for input.
+%  * session
+%    Print info on all loaded code, packs are shown with versions both from packs and info from <Pred>_version/2,3 if available (as per stoics.org.uk packs).
 %  * start 
-%    translates to starting ~Arg or starting ~Topic if Arg == true
-%  * task(Wch)  
-%    time of start/stop (Wch) of a task. Other values for Wch are allowed but printed as they come. Arg can be a term (as of Version 1.5).
+%    Translates to starting ~Arg or starting ~Topic if Arg == true.
+%  * task(Wch)
+%    Time of start/stop (Wch) of a task. Other values for Wch are allowed but printed as they come. 
+%    Arg can be a term (as of Version 1.5).
+%    Arg can include formatting tidles, and associated arguments should be passed via farg() option.
 %  * term
 %    Report the input term. The term can be named via option term_name(Tnm).
 %  * var
-%    reports variable name (arg(1)) and its current instantiation (arg(2))
+%    Reports variable name (arg(1)) and its current instantiation (arg(2))
+%  * version
+%    Reports version of software currently using:
+%    * predicate name of <Arg>_version/2,3 or <Arg>/2 (1st arg Version, 2nd arg release date),
+%    * Arg should be a term of arity 3 (Sw/Vers/Date) or arity 2 (Sw/Vrs/Date).
 %  * wrote 
-%    reports the writting of output on a file. Arg should be file specification suitable for locate/3.
+%    Reports the writting of output on a file. Arg should be file specification suitable for locate/3.
 %    Either loc(File,Exts) or simply File in which case Exts = ''.
 %    As of v2.0 the default is to print the basename, use path(abs) in Opts.
 %
 % As of v2.1 all debuc Goals work with options prefix(Pfx) and pred(Ar,Fn) (also synonymed to pred(Pid)).
 % 
+% v2.2 introduced ability to pass formatting patterns and arguments via farg() option. 
+%
 % See file examples/exo.pl for a test suit including at least one example from each debuc Goal.
 %
 %==
@@ -558,9 +588,10 @@ debug_portray( _Topic, _Term ).
 % @version  0.5 2014/??/??  added ns_sel
 % @version  1.1 2018/03/20  prefer +2 arity in debug_call/2
 % @version  1.2 2020/03/07  now can be used as a replacement for debug/3 (but with old 3rd arg behaviour, allowing eg 'true').
-% @version  1.3 2020/09/14  added canned calls info and enum, debuc/2,3,4
+% @version  1.3 2020/09/14  added debuc Goal info and enum, debuc/2,3,4
 % @version  2.0 2025/10/07  changed last two arguments, new option goal recogniser, pred/1, internal/1 & all/1
 % @version  2.1 2025/10/27  pid(F,A) & prefix() universal; call() fixed; doc; enum terms fix; ns_sel simplify
+% @version  2.2 2025/12/08  farg() option; depth() option in list and enum; debuc Goals: version, session.
 % @see file examples/exo.pl
 % @see debuc/3 shorthand for debug_call/3
 %
@@ -700,7 +731,8 @@ debug_call_topic( enum, InArg, Bogs, Topic ) :-
         number_codes( Len, LenCs ),
         length( LenCs, SpcLen ),
         debug_call_topic_list_delim( Left, Topic, 'Starting enumeration of list: ~w', Bogs ),
-        debug_call_topic_enum( Term, 1, SpcLen, Topic ),
+        ( memberchk(depth(Depth), Bogs) -> true; Depth = inf ),
+        debug_call_topic_enum( Term, 1, Depth, SpcLen, Topic ),
         debug_call_topic_list_delim( Left, Topic, 'Ended enumeration of list: ~w', Bogs )
         ;
         Term =.. [Func|Args],
@@ -709,7 +741,8 @@ debug_call_topic( enum, InArg, Bogs, Topic ) :-
         length( LenCs, SpcLen ),
         atomic_list_concat( ['Starting enumeration of term: ~w (func: ',Func,')'], StrMess ),
         debug_call_topic_list_delim( Left, Topic, StrMess, Bogs ),
-        debug_call_topic_enum( Args, 1, SpcLen, Topic ),
+        ( memberchk(depth(Depth), Bogs) -> true; Depth = inf ),
+        debug_call_topic_enum( Args, 1, Depth, SpcLen, Topic ),
         atomic_list_concat( ['Ended enumeration of term: ~w (func: ',Func,')'], EndMess ),
         debug_call_topic_list_delim( Left, Topic, EndMess, Bogs )
     ).
@@ -731,12 +764,28 @@ debug_call_topic( length, NamesPrv/ListsPrv, Bogs, Topic ) :-
 debug_call_topic( list, InArg, Bogs, Topic ) :-
     ground( InArg ),
     ( InArg = Left/List -> 
-        ( Left = Hdr/Ftr -> true ; Hdr = Left, Ftr = '' )
+        ( Left = Hdr/Ftr -> true ; Hdr = Left, Ftr = Left )
         ;
-        List = InArg, Hdr = '', Ftr = ''
+        List = InArg, Hdr = unamed, Ftr = unamed
     ),
     debug_call_topic_list_delim( Hdr, Topic, 'Starting listing of list: ~w', Bogs),
-    maplist( debug_message(Topic,'~w'), List ),
+    ( memberchk(depth(Depth),Bogs) -> 
+          length( Clean, Depth ),
+          ( append(Clean,[H|T],List) ->
+                    maplist( debug_message(Topic,'~w'), Clean ),
+                    length( [H|T], Xen ),
+                    ( Xen =:= 1 -> 
+                         Mess = '... + ~d other element'
+                         ;
+                         Mess = '... + ~d other elements'
+                    ),
+                    debug_message( Topic, Mess, Xen )
+                    ;
+                    maplist( debug_message(Topic,'~w'), List )
+          )
+          ;
+          maplist( debug_message(Topic,'~w'), List )
+    ),
     debug_call_topic_list_delim( Ftr, Topic, 'Ended listing of list: ~w', Bogs ).
 debug_call_topic( odir, Odir, Bogs, Topic ) :-
     ( exists_directory(Odir) ->
@@ -787,6 +836,161 @@ debug_call_topic( var, DbgTerm, Bogs, Topic ) :-
     Mess = 'Variable: ~a, value: ~w',
     debug_call_message_opts( Mess, [Var,Val], Message, Args, Bogs ),
     debug_message( Topic, Message, Args ).
+debug_call_topic( session, _Derm, Bogs, Topic ) :-
+     ( memberchk(in_module(Mod), Bogs) -> true; Mod = user),
+     current_prolog_flag( version_data, Swi ),  % Swi = swi(9, 3, 34, []).
+     Swi  = swi(Mj,Mn,Fx,Inc),
+     ( Inc == [] -> 
+          atomic_list_concat( [Mj,Mn,Fx], ':', Vers )
+          ;
+          atomic_list_concat( [Mj,Mn,Fx,Inc], ':',Vers )
+     ),
+     debug_message( Topic, 'Session Info', [] ),
+     ( current_prolog_flag(version_git, Git) -> % Git = '9.3.34-41-g8cf975236'.
+          atomic_list_concat( ['Interpreter is SWI-Prolog ',Vers,', [Git: ',Git,'].'], Mess )
+          ;
+          atomic_list_concat( ['Interpreter is SWI-Prolog ',Vers,'.'], Mess )
+     ),
+     debug_call_message_opts( Mess, [], Message, Args, Bogs ),
+     debug_message( Topic, Message, Args ),
+     % find where alias pack points to
+     once( (file_search_path(pack,PackPath),atomic(PackPath)) ),
+     debug_call_topic_session_predicate_file_prefixed( PackPath, Mod, pack, Lacks ),
+     findall( APack-ItsVers, (member(APack,Lacks),pack_property(APack,version(ItsVers))), PVs ),
+     findall( Stoic-VersInfo, (  Mod:predicate_property(P,file(_)),
+                                 functor(P,Fun,Ari),
+                                 atom_concat(Stoic,'_version',Fun),
+                                 ( Mod:predicate_property(P,imported_from(Stoic)) ->
+                                    true
+                                    ;
+                                    Mod:predicate_property(P,exported)
+                                 ),
+                                 ( Ari =:= 3 -> 
+                                        G =.. [Fun,Ser,Sdt,_],
+                                        call(Mod:G)
+                                        ;  % defaulty 2
+                                        Ari =:= 2,
+                                        G =.. [Fun,Ser,Sdt],
+                                        call(Mod:G)
+                                  ),
+                                  VersInfo = (Ser @< Sdt)
+                              ),
+                                 SVs ),
+     ( SVs == [] ->
+          true
+          ;
+          ( SVs == [_] ->
+               debug_message( Topic, 'Pack with predicated version info.', [] )
+               ;
+               debug_message( Topic, 'Packs with predicated version info.', [] )
+          ),
+          debug_call_topic_versions_predicated( SVs, PVs, Topic, RemPVs )
+     ),
+     ( RemPVs = [] -> 
+          true
+          ;
+          ( RemPVs = [_] ->
+               debug_message( Topic, 'Pack with version from pack file only.', [] )
+               ;
+               debug_message( Topic, 'Packs with version from pack file only.', [] )
+          ),
+          findall( _, (member(P-V,RemPVs),debug_message(Topic,'~w-~w',[P,V])), _ )
+     ),
+     once( (file_search_path(swi,SwiPath),atomic(SwiPath)) ),
+     debug_call_topic_session_predicate_file_prefixed( SwiPath, Mod, boot, Boots ),
+     debug_message( Topic, 'System boot files loaded.', [] ),
+     findall( _, (member(Boot,Boots),debug_message(Topic,'~w',[Boot])), _ ),
+     directory_file_path( SwiPath, library, LibPath ),
+     debug_call_topic_session_predicate_file_prefixed( LibPath, Mod, rel, Libs ),
+     ( Libs = [] ->
+          debug_message( Topic, 'No system libraries found loaded.', [] )
+          ;
+          ( Libs =[_] ->
+               debug_message( Topic, 'System library loaded.', [] )
+               ;
+               debug_message( Topic, 'System libraries loaded.', [] )
+          ),
+          findall( _, (member(Lib,Libs),debug_message(Topic,'~w',[Lib])), _ )
+     ),
+     findall( AppF, (   Mod:predicate_property(_,file(AppF)),
+                        ( atom_concat(PackPath,PackPsfx,AppF) ->
+                                            % fixme: check PackTop below, against loaded ?
+                                   catch( atomic_list_concat([_Empty,_PackTop,TopSub|_],'/',PackPsfx),_,fail),
+                                   \+ memberchk(TopSub,[prolog,src])
+                                   ;
+                                   true
+                        ),
+                        \+atom_concat(SwiPath,_,AppF)
+                    ),
+                         AppFsL ),
+     sort( AppFsL, AppFs ),
+     ( AppFs = [] ->
+          debug_message( Topic, 'There where no application files loaded.', [] )
+          ;
+          ( AppFs = [_] ->
+               debug_message( Topic, 'There is one application file loaded.', [] )
+               ;
+               debug_message( Topic, 'Application files loaded.', [] )
+          ),
+          findall( AnAF, (member(AnAF,AppFs),debug_message(Topic,'~w',[AnAF])), _ )
+     ),
+     debug_message( Topic, 'Session Info End', [] ).
+debug_call_topic( version, Derm, Bogs, Topic ) :-
+     ( atomic(Derm) -> 
+          atom_concat( Derm, '_version', Verm ),
+          ( current_predicate(Verm/2) ->
+               Goal =.. [Verm,V,D],
+               once(Goal)
+               ;
+               ( current_predicate(Verm/3) ->
+                    Goal =.. [Verm,V,D,_],
+                    once(Goal)
+                    ;
+                    ( pack_property(Derm,version(V)) ->
+                         D = no_date
+                         ;
+                         ( current_predicate(Derm/2) -> 
+                              Goal =.. [Derm,V,D],
+                              once(Goal)
+                              ;
+                              V = no_vers, D = no_date
+                         )
+                    )
+               )
+          ),
+          Mrgs = [Derm,V,D]
+          ;
+          ( functor(Derm,_,2) ->
+               arg( 1, Derm, Sw ),
+               arg( 2, Derm, V ),
+               Mrgs = [Sw,V,no_date]
+               ;
+               ( functor(Derm,_,3) ->
+                    arg( 1, Derm, Sw ),
+                    arg( 2, Derm, V ),
+                    arg( 3, Derm, D ),
+                    Mrgs = [Sw,V,D]
+                    ;
+                    Mrgs = [Derm,no_vers,no_date]
+               )
+          )
+     ),
+     ( D == no_date ->
+          (   V == no_vers ->
+               Mess = 'Using ~w (no version or publication date available).',
+               Mrgs = [A|_],
+               Crgs = [A]
+               ;
+               Mess = 'Using ~w, at version: ~w.',
+               Mrgs = [A,B|_],
+               Crgs = [A,B]
+          )
+          ;
+          Mess = 'Using ~w, at version: ~w (published on: ~w).',
+          Mrgs = Crgs
+     ),
+     debug_call_message_opts( Mess, Crgs, Message, Args, Bogs ),
+     debug_message( Topic, Message, Args ).
 debug_call_topic( wrote, ForLoc, Bogs, Topic ) :-
     ( ForLoc = loc(Spec,Ext) -> true; Spec=ForLoc, Ext = '' ),
     catch( locate(Spec,Ext,Loc), Excp, true ),
@@ -806,8 +1010,8 @@ debug_call_topic( input, ForLoc, Bogs, Topic ) :-
 debug_call_topic( task(Whc), Task, Bogs, Topic ) :-
     datime_readable( Readable ),
     debug_call_topic_time_which_readable( Whc, Whcable ),
-    atomic_list_concat( [Readable,' ',Whcable,' task: ~w.'], Mess ),
-    debug_call_message_opts( Mess, [Task], Message, Args, Bogs ),
+    atomic_list_concat( [Readable,' ',Whcable,' task: ', Task], Mess ),
+    debug_call_message_opts( Mess, [], Message, Args, Bogs ),
     debug_message( Topic, Message, Args ).
 debug_call_topic( start, Arg, Bogs, Topic ) :-
     Mess = 'Starting: ~w',
@@ -841,17 +1045,60 @@ debug_call_topic( ns_sel, Term, Bogs, Topic ) :-
     debug_call_message_opts( Mess, MArgs, Message, Args, Bogs ),
     debug_message( Topic, Message, Args ).
 
-debug_call_topic_enum( [], _I, _Len, _Topic ).
-debug_call_topic_enum( [H|T], I, Len, Topic ) :-
-    number_codes( I, ICs ),
-    length( ICs, ICsLen ),
-    PadLen is Len - ICsLen,
-    findall( ' ', between(1,PadLen,_), Spcs ),
-    atomic_list_concat( Spcs, '', Pad ),
-    atomic_list_concat( [Pad,'~d.~w'], '', Mess ),
-    debug_message( Topic, Mess, [I,H] ),
+debug_call_topic_session_predicate_file_prefixed( Path, Mod, Iface, Lacks ) :-
+     findall( APack, ( Mod:predicate_property(_Pead, file(File)), 
+                             atom_concat(Path, Psfx, File), 
+                             ( Iface == pack -> 
+                                   atomic_list_concat(['',APack|_], '/', Psfx)
+                                   ;
+                                   ( atom_concat('/',APack,Psfx) -> 
+                                        ( Iface == boot ->
+                                             \+ atom_concat( library, _, APack )
+                                             ;
+                                             true
+                                        )
+                                        ;
+                                        Psfx = APack
+                                   )
+                             )
+                           ),
+                              AllPacks ),
+     sort( AllPacks, Lacks ).
+
+debug_call_topic_versions_predicated( [], PVs, _Topic, RemPVs ) :-
+     PVs = RemPVs.
+debug_call_topic_versions_predicated( [Pack-SVers|T], PVs, Topic, RemPVs ) :-
+     ( select(Pack-InfoVer,PVs,NxtPVs) ->
+          debug_message( Topic, '~w-~w (Pack file version: ~w)', [Pack,SVers,InfoVer] )
+          ;
+          debug_message( Topic, '~w-~w', [Pack,SVers] ),
+          PVs = NxtPVs
+     ),
+     debug_call_topic_versions_predicated( T, NxtPVs, Topic, RemPVs ).
+
+debug_call_topic_enum( [], _I, _Depth, _Len, _Topic ).
+debug_call_topic_enum( [H|T], I, Depth, Len, Topic ) :-
+    ( I > Depth -> 
+          Rem = [],
+          length( [H|T], HTen ),
+          ( HTen =:= 1 -> 
+               Mess = '... + ~d other element'
+               ;
+               Mess = '... + ~d other elements'
+          ),
+          debug_message( Topic, Mess, HTen )
+          ;
+          T = Rem,
+          number_codes( I, ICs ),
+          length( ICs, ICsLen ),
+          PadLen is Len - ICsLen,
+          findall( ' ', between(1,PadLen,_), Spcs ),
+          atomic_list_concat( Spcs, '', Pad ),
+          atomic_list_concat( [Pad,'~d.~w'], '', Mess ),
+          debug_message( Topic, Mess, [I,H] )
+    ),
     J is I + 1,
-    debug_call_topic_enum( T, J, Len, Topic ).
+    debug_call_topic_enum( Rem, J, Depth, Len, Topic ).
 
 debug_call_topic_list_delim( ListName, Topic, Std, Bogs ) :-
      debug_call_message_opts( Std, [ListName], Mess, Args, Bogs ), 
@@ -909,11 +1156,12 @@ debug_call_pred_in_opts_mess( Std, Opt, Prefixed, Prgs, Bogs ) :-
      ( debug_call_pred_in_opts(Pid, Bogs)  ->
           Pfx = 'Predicate: ~w',
           debug_message_prefixed_atom( Pfx, Std, Prefixed ),
-          Prgs = [Pid|Opts]
+          PrgsPrv = [Pid|Opts]
           ;
           Prefixed = Std,
-          Prgs = Opts
-     ).
+          PrgsPrv = Opts
+     ),
+     debug_call_pred_in_opts_mess_format_args( PrgsPrv, Prgs, Bogs ).
 
 debug_call_pred_in_opts( Pid, Opts ) :-
     memberchk( pred(Fun,Ar), Opts ),
@@ -922,6 +1170,10 @@ debug_call_pred_in_opts( Pid, Opts ) :-
 debug_call_pred_in_opts( Pid, Opts ) :-
     memberchk( pred(Pid), Opts ).
 
+debug_call_pred_in_opts_mess_format_args( PrgsPrv, Prgs, Bogs ) :-
+     findall( Farg, member(farg(Farg),Bogs), Fargs ),
+     append( PrgsPrv, Fargs, Prgs ).
+
 debug_message_prefixed_atom( Pfx, Standard, Prefixed ) :-
     sub_atom( Standard, 0, 1, Aft, Fst ),
     downcase_atom( Fst, Low ),
